@@ -9,6 +9,8 @@ kml_layer.SpatialPixels <- function(
   raster_name,
   plot.legend = TRUE,
   metadata = NULL,
+  png.width = gridparameters(obj)[1,"cells.dim"], 
+  png.height = gridparameters(obj)[2,"cells.dim"],  
   ...
   ){
 
@@ -90,14 +92,16 @@ kml_layer.SpatialPixels <- function(
   }
 
   # Plotting the image
-  png(filename = raster_name, bg = "transparent", type="cairo-png")
+  png(filename = raster_name, bg = "transparent", type = "cairo-png", width = png.width, height = png.height)
   par(mar = c(0, 0, 0, 0), xaxs = "i", yaxs = "i")
   if(!is.na(charmatch("z.lim", names(call)))){ 
-    z.lim <- eval(call[["z.lim"]])
+    z.lim <- eval(call[["z.lim"]]) 
     r <- calc(r, fun=function(x){ x[x < z.lim[1]] <- z.lim[1]; return(x)}) 
-    r <- calc(r, fun=function(x){ x[x > z.lim[2]] <- z.lim[2]; return(x)}) 
+    r <- calc(r, fun=function(x){ x[x > z.lim[2]] <- z.lim[2]; return(x)})
+    raster::image(r, col = colour_scale, zlim = z.lim, frame.plot = FALSE, main="")
+  } else {
+    raster::image(r, col = colour_scale, frame.plot = FALSE, main="")
   }
-  raster::image(r, col = colour_scale, zlim = z.lim, frame.plot = FALSE, main="")
   dev.off()
 
   ## There is a bug in Google Earth that does not allow transparency of PNGs:
